__builtin__.type

Module __builtin__ :: Class type |
[show private | hide private]
[frames | no frames]

## Type type

    object --+
             |
            type

    type(object) -> the object's type
    type(name, bases, dict) -> a new type

Method Summary
| ``__call__`(x, ...)` x.__call__(...) <==> x(...)...
| ``__cmp__`(x, y)` x.__cmp__(y) <==> cmp(x,y)...
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name...
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name...
| ``__hash__`(x)` x.__hash__() <==> hash(x)...
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T...
| ``__repr__`(x)` x.__repr__() <==> repr(x)...
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value...
list of immediate subclasses | ``__subclasses__`()` __subclasses__() -> list of immediate subclasses...
list | ``mro`()` return a type's method resolution order...
Inherited from object
| ``__init__`(...)` x.__init__(...) initializes x; see x.__class__.__doc__ for signature...
| ``__reduce__`(...)` helper for pickle...
| ``__reduce_ex__`(...)` helper for pickle...
| ``__str__`(x)` x.__str__() <==> str(x)...

Class Variable Summary
`type` | `__base__` = `__builtin__.object`
`tuple` | `__bases__` = `(<type 'object'>,)`
`int` | `__basicsize__` = 420
`int` | `__dictoffset__` = 132
`int` | `__flags__` = 21995
`int` | `__itemsize__` = 20
`tuple` | `__mro__` = `(<type 'type'>, <type 'object'>)`
`str` | `__name__` = `'type'`
`int` | `__weakrefoffset__` = 184

Method Details

### __call__(x, ...) (Call operator)
    x.__call__(...) <==> x(...)
    Returns:
        x(...)

### __cmp__(x, y) (Comparison operator)
    x.__cmp__(y) <==> cmp(x,y)
    Returns:
        cmp(x,y)

### __delattr__(...)
    x.__delattr__('name') <==> del x.name
Overrides: `__builtin__.object.__delattr__`

### __getattribute__(...)
    x.__getattribute__('name') <==> x.name
Overrides: `__builtin__.object.__getattribute__`

### __hash__(x) (Hashing function)
    x.__hash__() <==> hash(x)
    Returns:
        hash(x)
Overrides: `__builtin__.object.__hash__`

### __new__(T, S, ...)
    T.__new__(S, ...) -> a new object with type S, a subtype of T
    Returns:
        a new object with type S, a subtype of T
Overrides: `__builtin__.object.__new__`

### __repr__(x) (Representation operator)
    x.__repr__() <==> repr(x)
    Returns:
        repr(x)
Overrides: `__builtin__.object.__repr__`

### __setattr__(...)
    x.__setattr__('name', value) <==> x.name = value
Overrides: `__builtin__.object.__setattr__`

### __subclasses__()
    __subclasses__() -> list of immediate subclasses
Returns: list of immediate subclasses

### mro()
    return a type's method resolution order
Returns: list

Class Variable Details

    ### __bases__ Type: `tuple` Value:
        (<type 'object'>,)

    ### __basicsize__ Type: `int` Value:
        420

    ### __dictoffset__ Type: `int` Value:
        132

    ### __flags__ Type: `int` Value:
        21995

    ### __itemsize__ Type: `int` Value:
        20

    ### __mro__ Type: `tuple` Value:
        (<type 'type'>, <type 'object'>)

    ### __name__ Type: `str` Value:
        'type'

    ### __weakrefoffset__ Type: `int` Value:
        184

Generated by Epydoc 2.1 on Sat Jul 7 23:24:47 2007 | http://epydoc.sf.net